@@ -122,10 +122,10 @@ identical(st_read(quiet = TRUE, csv, options = "AUTODETECT_TYPE=Yes")$Int32[3],
 
 if ("GML" %in% st_drivers()$name) {
   gml = system.file("gml/fmi_test.gml", package = "sf")
-  print(dim(st_read(gml, quiet = TRUE)))
+  print(dim(st_read(gml, quiet = TRUE, use_stream = FALSE)))
   gml = system.file("gml/20170930_OB_530964_UKSH.xml.gz", package = "sf")
-  print(dim(st_read(gml, layer = "Parcely", quiet = TRUE)))
-  print(dim(st_read(gml, layer = "Parcely", int64_as_string=TRUE, quiet = TRUE)))
+  print(dim(st_read(gml, layer = "Parcely", quiet = TRUE, use_stream = FALSE)))
+  print(dim(st_read(gml, layer = "Parcely", int64_as_string=TRUE, quiet = TRUE, use_stream = FALSE)))
 }
 
 # logical:
