@@ -12,8 +12,8 @@ test_that("s2 roundtrips work", {
 
 test_that("as_s2_geography() is defined for sf and sfc objects", {
   nc = st_read(system.file("shape/nc.shp", package="sf"), quiet = TRUE)
-  expect_is(s2::as_s2_geography(nc), "s2_geography")
-  expect_is(s2::as_s2_geography(st_geometry(nc)), "s2_geography")
+  expect_s3_class(s2::as_s2_geography(nc), "s2_geography")
+  expect_s3_class(s2::as_s2_geography(st_geometry(nc)), "s2_geography")
 })
 
 test_that("s2 polygon creation", {
